@@ -27,7 +27,12 @@
 /* For now, we hardcode this, but in the future,
  * we can detect capabilities of the MySQL libraries
  * we're talking to */
+#if defined(__WIN__)
+#define MYSQL_ASYNC 0
+#else
 #define MYSQL_ASYNC 1
+#endif
+
 
 /*
  * This is the version of MySQL wherer
@@ -212,6 +217,9 @@ typedef struct imp_sth_fbh_st {
     int            charsetnr;
     double         ddata;
     long           ldata;
+#if MYSQL_VERSION_ID < FIELD_CHARSETNR_VERSION 
+    unsigned int   flags;
+#endif
 } imp_sth_fbh_t;
 
 
